@@ -17,11 +17,12 @@
 #'  If \code{\var{age}} is also \code{TRUE}, function will return Pr(Geolocation, Age, Sex | Race).
 #' @param census.geo An optional character vector specifying what level of 
 #' geography to use to merge in U.S. Census 2010 geographic data. Currently
-#' \code{"county"}, \code{"tract"}, or \code{"block"} are supported.
+#' \code{"county"}, \code{"tract"}, \code{"block"}, and \code{"place"} are supported.
 #' @param retry The number of retries at the census website if network interruption occurs.
 #' @return Output will be an object of class \code{list} indexed by state. 
-#' Output will contain the following elements: \code{state}, \code{age}, \code{sex}, 
-#' \code{county}, \code{tract} and \code{block}. 
+#' Output will contain a subset of the following elements: 
+#' \code{state}, \code{age}, \code{sex}, 
+#' \code{county}, \code{tract}, \code{block}, and \code{place}.
 #' 
 #' @export
 #'
@@ -36,19 +37,23 @@ get_census_data <- function(key, states, age = FALSE, sex = FALSE, census.geo =
   
   CensusObj <- NULL
   for (s in states) {
-      CensusObj[[s]] <- list(state = s, age = age, sex = sex)
-      if (census.geo == "block") {
-        block <- census_geo_api(key, s, geo = "block", age, sex, retry)
-        CensusObj[[s]]$block <- block
-      }
-      if ((census.geo == "block") || (census.geo == "tract")) {
-        tract <- census_geo_api(key, s, geo = "tract", age, sex, retry)
-        CensusObj[[s]]$tract <- tract
-      }
-      if ((census.geo == "block") || (census.geo == "tract") || (census.geo == "county")) {
-          county <- census_geo_api(key, s, geo = "county", age, sex, retry)
-        CensusObj[[s]]$county <- county
-      }
+    CensusObj[[s]] <- list(state = s, age = age, sex = sex)
+    if (census.geo == "place") {
+      place <- census_geo_api(key, s, geo = "place", age, sex, retry)
+      CensusObj[[s]]$place <- place
+    }
+    if (census.geo == "block") {
+      block <- census_geo_api(key, s, geo = "block", age, sex, retry)
+      CensusObj[[s]]$block <- block
+    }
+    if ((census.geo == "block") || (census.geo == "tract")) {
+      tract <- census_geo_api(key, s, geo = "tract", age, sex, retry)
+      CensusObj[[s]]$tract <- tract
+    }
+    if ((census.geo == "block") || (census.geo == "tract") || (census.geo == "county")) {
+      county <- census_geo_api(key, s, geo = "county", age, sex, retry)
+      CensusObj[[s]]$county <- county
+    }
   }
   return(CensusObj)
 }
